#!/usr/bin/env python
"""
Copyright (C) 2017, Intel Corporation. All rights reserved.

fwu helper functions for mei driver
"""
import os
import errno
import struct
import mei

UUID = '309dcde8-ccb1-4062-8f78-600115a34327'

def connect(mei_fd):
    '''Connect to FWU client'''
    return mei.connect(mei_fd, UUID)

def req_fw_info(mei_fd):
    '''Send FW info request'''
    buf_write = struct.pack("I", 0x0000001E)
    return os.write(mei_fd, buf_write)

def fw_info_parse(buf_read):
    '''Parse FW info'''
    if len(buf_read) != 456:
        raise IOError(errno.EMSGSIZE,
                      "Wrong FW info message size %d" % len(buf_read))
    return struct.unpack("4I4H4H2I32B7I4H2I16BH4B2I32B4H4H12II3IH48I", buf_read)

#SVN is at 51

def get_fw_info(mei_fd):
    '''Read FW info'''
    buf = os.read(mei_fd, 10000)
    return fw_info_parse(buf)

def fw_info(mei_fd):
    '''Receive FW info'''
    req_fw_info(mei_fd)
    return get_fw_info(mei_fd)
